@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 ## NOTE: both url/socket need to have the query string
 ## url-encoded (percent format, e.g. %C3) if unicode.
@@ -603,34 +603,39 @@ Net::API::Nominatim - Perl client for local or public OpenStreetMap Nominatim Ge
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 !NOMINATIM!
 
 L<Nominatim|https://nominatim.org/>
 uses L<OpenStreetMap|https://www.openstreetmap.org>
-data to find locations on Earth by name and
+data to find coordinates for locations on Earth by name and
 address (geocoding). It can also do the reverse, find an address
-for any location on the planet.
+for any location on the planet, given coordinates.
 
 Nominatim provides a public, free and un-restricted service,
-subject to fair usage, at L<https://nominatim.openstreetmap.org/ui/search.html?%3Cparams%3E>
+subject to fair usage, at L<https://nominatim.openstreetmap.org/ui/search.html>
 for all of your geocoding needs.
 
-Most importantly, a Nominatim server can easily and in-expensively be
-installed locally if you intend to geocode heavily. The geocoding data 
-Nominatim uses is open source, provided by L<OpenStreetMap|https://www.openstreetmap.org>.
+Most importantly, a Nominatim server can be easily
+installed locally if you intend to geocode heavily
+or you do not have network access. Nominatim uses open source
+geocoding data  provided by L<OpenStreetMap|https://www.openstreetmap.org>.
 When you install Nominatim locally, you also install this geocoding data
 locally. The data is broken into different geographical locations so you
-can geocode for just your country, your continent or the whole planet
-without relying on the closely guarded data provided by the usual big Capitalist players.
+can geocode for just your district, your country,
+your continent or the whole planet
+without relying on the closely guarded and
+prohibitevely copyrighted (really?) data
+provided by the usual big Capitalist players.
 
-If you decide to install Nominatim locally for your own geocoding needs
-it is also worth to consider installing a Map Tile Server in order to
-provide your own maps!
+If you decided to install Nominatim locally for your own geocoding needs
+it is also worth installing a Map Tile Server in order to
+provide your own open source maps!
 All the data open source, courtesy of L<OpenStreetMap|https://www.openstreetmap.org>.
-Have a look at L<this guide|https://switch2osm.org/serving-tiles/> for how
-to completely break free and never again have to rely on the usual big Capitalist players.
+Have a look at the guide at L<switch2osm.org||https://switch2osm.org/serving-tiles/> for how
+to completely break free and never again have to rely on the usual
+big Capitalist players.
 
 For local installations, Nominatim can be accessed via a UNIX socket.
 This should be the fastest method to geocode locally.
@@ -638,10 +643,19 @@ Unless you have implemented intermediate caching. Alternatively,
 for local or public Nominatim service, you can make a simple
 HTTP/GET query.
 
+This module offers both local UNIX socket and
+HTTP/GET queries.
+
 Remember, Capitalism is changing really fast, to the uglier,
+to the hungrier, to the scummier,
 by the day.
 Right now it is very hungry. It will become even more so.
-As a matter of life or death, break away from it NOW.
+It is not a matter of "immoral", "stupid", "greedy"
+leaders "running" (yeah! right) the show, it is a matter
+of processes. The processes will continue irrespective of leaders.
+To the End.
+
+As a matter of life or death, break away from Capitalism NOW.
 
 
 =head1 SYNOPSIS
@@ -651,7 +665,7 @@ server, either via a local UNIX socket, if Nominatim is installed
 locally, or via HTTP/GET requests if you rely on the public Nominatim
 service. The L<Nominatim API|https://nominatim.org/release-docs/develop/api/Overview>
 is extensive. But the current module covers only basic forward and reverse
-geocoding queries only with C<search>, C<reverse> and C<status>.
+geocoding queries only with C</search>, C</reverse> and C</status>.
 
 Example usage:
 
@@ -757,8 +771,8 @@ This is HASH_REF with some of these keys:
 B<WARNING>: this object will have its UserAgent String altered to comply with Nominatim's
 usage policy which states it must be a string to identify the client. So, this will be
 our client's UserAgent String. If you intend to use the specified L<LWP::UserAgent> object
-then save its agent string (C<my $oldstr = $ua->agent;>) and reload it later
-(C<$ua->agent($oldstr);>).
+then save its agent string (C<my $oldstr = $ua-E<gt>agent;>) and reload it later
+(C<$ua-E<gt>agent($oldstr);>).
 
 =item * C<useragent-string> : DO NOT SPECIFY your own UserAgent String PLEASE. There is
 already a default for this which identifies this current client uniquely. So, you do
@@ -894,7 +908,7 @@ Nominatim, the Map tile server and GeoDesk-Gol mentioned below.
 This data can also be inserted into a L<PostGIS|https://postgis.net/>
 database and make your own queries on it.
 
-I have already mentioned at the L<INTRODUCTION>
+I have already mentioned in the L<INTRODUCTION>
 that it is quite easy and, definetely, not discouraged to
 host a Nominatim server locally. It will be totally self-sufficient
 in the sense that it will not need to access any external
@@ -906,17 +920,18 @@ Check for what resources are required though. For small geographical
 areas, resources are moderate.
 
 You can also host your own map tiles and serve your own
-high-quality maps without relying ever again on the big players.
+high-quality maps, styled as you like,
+without relying ever again on the big Capitalist players.
 Have a look at the guide offered at L<Switch2osm|https://switch2osm.org>
-for how you can get started with this, although the resources are
-bigger and assembling the toolchain is far more complicated
-than with Nominatim.
+for how you can get started with this, although far more resources are
+needed and assembling the toolchain is more complicated
+than with Nominatim. But it works, just follow the L<guide|https://switch2osm.org>.
 
 Another open source project is L<GeoDesk|https://github.com/clarisma/geodesk>
 and the command line query tool L<GeoDesk-Gol|https://github.com/clarisma/geodesk-gol>.
 This tool takes OpenStreetMap data for any geographical location,
 in the form of C<.osm.pbf> files (see above on where to download them from)
-and constructs a portable file-based database
+and constructs a portable, file-based database
 (called Gol, as in scoring a goal!) which you can then enquire with
 the provided command line tool. There is no need to create a L<PostGIS|https://postgis.net/>
 database and insert data into it. The Gol file is all you need
@@ -939,16 +954,36 @@ server or a local installation of Nominatim. It comes in two flavours:
 
 =over 2
 
-=item C<make livetesturl> : tests HTTP/GET queries to the public Nominatim server at
+=item * C<make livetesturl> : tests HTTP/GET queries to the public Nominatim server at
 L<https://nominatim.openstreetmap.org/ui/search.html>.
 
-=item C<make livetestlocal> : tests UNIX socket queries to a local Nominatim installation
+=item * C<make livetestlocal> : tests socket queries to a local Nominatim installation
 via its local UNIX socket whose path can be set in all the test files in directory
 C<xt/live/local-socket/> via the C<$sockpath> variable,
 currently pointing to C</run/nominatim/nominatim.sock>.
 
 =back
 
+=head1 RESPONSIBLE USE
+
+Be responsible in using the public Nominatim service and please
+observe their usage policy, summarised as
+
+=over 2
+
+=item * Uniquely and persistently identify your client.
+
+=item * No more than one request per second.
+
+=back
+
+The first clause we observe here by setting the default User-Agent string.
+
+The second clause is up to you. Please be responsible and do not forget
+that if you are going to do a lot of geocoding install your own Nominatim
+server locally. Then you can query it to your heart's content.
+
+
 =head1 AUTHOR
 
 Andreas Hadjiprocopis, C<< <bliako at cpan.org> >>
